<?php
namespace app\alisms\loglic;

require './apps/alisms/vendor/autoload.php';

use AlibabaCloud\SDK\Dysmsapi\V20170525\Dysmsapi;
use \Exception;
use AlibabaCloud\Tea\Exception\TeaError;
use AlibabaCloud\Tea\Utils\Utils;

use Darabonba\OpenApi\Models\Config;
use AlibabaCloud\SDK\Dysmsapi\V20170525\Models\SendSmsRequest;
use AlibabaCloud\Tea\Utils\Utils\RuntimeOptions;

class Send
{
    protected $error = '';
    
    public function getError()
    {
        return $this->error;
    }
    
    public function createClient($accessKeyId='', $accessKeySecret='')
    {
        $config = new Config([
            "accessKeyId"     => trim($accessKeyId),
            "accessKeySecret" => trim($accessKeySecret)
        ]);
        $config->endpoint = "dysmsapi.aliyuncs.com";
        return new Dysmsapi($config);
    }
    
    public function main($signName='阿里云短信测试', $templateCode='SMS_154950909', $templateParam='code', $phoneNumber='', $content='')
    {
        $client = $this->createClient(config('alisms.keyId'), config('alisms.keySecret'));

        $sendSmsRequest = new SendSmsRequest([
            "signName"      => $signName,
            "templateCode"  => $templateCode,
            "phoneNumbers"  => $phoneNumber,
            "templateParam" => json_encode([$templateParam=>$content])
        ]);
        $runtime = new RuntimeOptions([
            "ignoreSSL" => true
        ]);
        try {
            $client->sendSmsWithOptions($sendSmsRequest, $runtime);
        }catch (Exception $error) {
            if (!($error instanceof TeaError)) {
                $error = new TeaError([], $error->getMessage(), $error->getCode(), $error);
            }
            $this->error = $error->getMessage();
            return false;
        }
        return true;
    }
}